import Vue from 'vue'

import Cache from './utils/cache'

import 'normalize.css/normalize.css' // a modern alternative to CSS resets

import Element from 'element-ui'
import './styles/element-variables.scss'

import '@/styles/index.scss' // global css
import 'flex.css'

import App from './App'
import store from './store'
import router from './router'
import Api from './api'

import Lodash from 'lodash'

import './utils/iconfont' // icon
import './permission' // permission control
import './utils/error-log' // error log
import request from './utils/request' // request
import { checkAuth } from './utils/auth' // check auth
import purview from './config/purview' // config purview

// 自定义指令
import Directives from './directive'

import * as filters from './filters'

Vue.use(Element, {
  size: Cache.get('size') || 'medium' // set element-ui default size
})

// register global utility filters
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})

Vue.use({
  install(Vue, options) {
    Vue.prototype.$api = Api
    Vue.prototype.$request = request

    // 校验权限
    Vue.prototype.$checkAuth = checkAuth
    window['$checkAuth'] = checkAuth

    // 权限
    Vue.prototype.purview = purview
    window['purview'] = purview

    // lodash
    Vue.prototype._ = Lodash
  }
})

Vue.use(Directives)

Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
