import { asyncRoutes, constantRoutes } from '@/router'

/**
 * Use meta.role to determine if the current user has permission
 * @param auths
 * @param route
 */
function hasAuth(auths, route) {
  if (auths.length && route.meta && route.meta.auth) {
    return auths.includes(route.meta.auth)
  } else {
    return true
  }
}

/**
 * Filter asynchronous routing tables by recursion
 * @param routes asyncRoutes
 * @param auths
 */
export function filterAsyncRoutes(routes, auths) {
  const res = []

  routes.forEach(route => {
    const tmp = { ...route }
    if (hasAuth(auths, tmp)) {
      if (tmp.children) {
        tmp.children = filterAsyncRoutes(tmp.children, auths)
      }
      res.push(tmp)
    }
  })

  return res
}

const state = {
  routes: [],
  addRoutes: []
}

const mutations = {
  SET_ROUTES: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
  }
}

const actions = {
  generateRoutes({ commit }, auths) {
    return new Promise(resolve => {
      let accessedRoutes
      // 一个权限都没有表示所有的权限都有，即超管
      // process.env.NODE_ENV === 'development' ||
      if (auths.length === 0) {
        accessedRoutes = asyncRoutes || []
      } else {
        accessedRoutes = filterAsyncRoutes(asyncRoutes, auths)
      }
      commit('SET_ROUTES', accessedRoutes)
      resolve(accessedRoutes)
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
