import api from '@/api'
import { getToken, setToken, removeToken } from '@/utils/auth'
import { resetRouter } from '@/router'
import defaultSettings from '@/settings'
const { avatarUrl } = defaultSettings
const getDefaultState = () => {
  return {
    token: getToken(),
    name: '',
    avatar: avatarUrl,
    auths: null
  }
}

const state = getDefaultState()

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AUTHS: (state, auths) => {
    state.auths = auths
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { username, password, key, captcha } = userInfo
    return new Promise((resolve, reject) => {
      api.user.login({ username: username.trim(), password: password, key: key, captcha: captcha }).then(response => {
        const { data } = response
        commit('SET_TOKEN', data.token)
        setToken(data.token)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // get user info
  getAuths({ commit, state }) {
    return new Promise((resolve, reject) => {
      api.user.getAuths(state.token).then(response => {
        const { data } = response

        if (!data) {
          return reject('Verification failed, please Login again.')
        }

        const { auths } = data

        commit('SET_AUTHS', auths)
        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },

  // user logout
  logout({ commit }) {
    return new Promise((resolve, reject) => {
      api.user.logout().then(() => {
        removeToken() // must remove  token  first
        resetRouter()
        commit('RESET_STATE')
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

